-- all functions below are optional and can be left out

--[[

function OnModPreInit()
	print("Mod - OnModPreInit()") -- First this is called for all mods
end

function OnModInit()
	print("Mod - OnModInit()") -- After that this is called for all mods
end

function OnModPostInit()
	print("Mod - OnModPostInit()") -- Then this is called for all mods
end

function OnPlayerSpawned( player_entity ) -- This runs when player entity has been created
	GamePrint( "OnPlayerSpawned() - Player entity id: " .. tostring(player_entity) )
end

function OnWorldInitialized() -- This is called once the game world is initialized. Doesn't ensure any world chunks actually exist. Use OnPlayerSpawned to ensure the chunks around player have been loaded or created.
	GamePrint( "OnWorldInitialized() " .. tostring(GameGetFrameNum()) )
end

function OnWorldPreUpdate() -- This is called every time the game is about to start updating the world
	GamePrint( "Pre-update hook " .. tostring(GameGetFrameNum()) )
end

function OnWorldPostUpdate() -- This is called every time the game has finished updating the world
	GamePrint( "Post-update hook " .. tostring(GameGetFrameNum()) )
end

]]--

-- This code runs when all mods' filesystems are registered
-- ModLuaFileAppend( "data/scripts/gun/gun_actions.lua", "mods/example/files/actions.lua" ) -- Basically dofile("mods/example/files/actions.lua") will appear at the end of gun_actions.lua
-- ModMagicNumbersFileAdd( "mods/example/files/magic_numbers.xml" ) -- Will override some magic numbers using the specified file
-- ModRegisterAudioEventMappings( "mods/example/files/audio_events.txt" ) -- Use this to register custom fmod events. Event mapping files can be generated via File -> Export GUIDs in FMOD Studio.
-- ModMaterialsFileAdd( "mods/example/files/materials_rainbow.xml" ) -- Adds a new 'rainbow' material to materials

--print("Example mod init done")

function get_foreshadowing(hours, minutes, seconds)
	local timestring = "YOU HAVE "
	
	if hours ~= 0 then
		timestring = timestring .. hours .. " HOUR" .. (hours == 1 and "" or "S")
	end
	
	if minutes ~= 0 then
		if hours ~= 0 then
			if seconds ~= 0 then
				timestring = timestring .. ", "
			else
				timestring = timestring .. " AND "
			end
		end
		
		timestring = timestring .. minutes .. " MINUTE" .. (minutes == 1 and "" or "S")
	end
	
	if seconds ~= 0 then
		if hours ~= 0 or minutes ~= 0 then
			timestring = timestring .. " AND "
		end
		
		timestring = timestring .. seconds .. " SECOND" .. (seconds == 1 and "" or "S")
	end
	
	if hours ~= 0 or minutes ~= 0 or seconds ~= 0 then
		timestring = timestring .. " TO LIVE."
	else
		timestring = timestring .. "NO TIME."
	end
	
	return timestring
end

function OnPlayerSpawned( player_entity ) -- This runs when player entity has been created
	dofile_once("mods/lifetimer/lifetime.lua")
	local game_frames = GameGetFrameNum() - 10
	
	seconds = seconds + math.floor(frames / 60)
	frames = frames % 60
	
	minutes = minutes + math.floor(seconds / 60)
	seconds = seconds % 60
	
	hours = hours + math.floor(minutes / 60)
	minutes = minutes % 60
	
	local total_lifetime = hours * 216000 + minutes * 3600 + seconds * 60 + frames
	local timeleft = total_lifetime - game_frames
	
	EntityAddComponent(player_entity, "LuaComponent", {
		script_source_file = "mods/lifetimer/lifetimer_files/lifetimer_drama.lua",
		execute_times = "1",
		remove_after_executed = "1",
		execute_every_n_frame = total_lifetime - game_frames - 60
	})
	
	-- YOU HAVE HOURS TO LIVE.
	-- YOU HAVE MINUTES TO LIVE.
	-- YOU HAVE SECONDS TO LIVE.
	-- YOU HAVE HOURS AND MINUTES TO LIVE.
	-- YOU HAVE HOURS AND SECONDS TO LIVE.
	-- YOU HAVE MINUTES AND SECONDS TO LIVE.
	-- YOU HAVE HOURS, MINUTES AND SECONDS TO LIVE.
	
	local timestring = get_foreshadowing(hours, minutes, seconds)
	GamePrintImportant(timestring, "")
	print("LIFETIME:", hours, minutes, seconds)
	
	--[[d 
	EntityAddComponent(player_entity, "LifetimeComponent", {
		lifetime = lifetime
	})
	]]--
	
	EntityLoad("mods/lifetimer/lifetimer_files/lifetimer_gui.xml")
end
